type Point = {
  'type': 'Point'
  'coordinates': [
    number,
    number,
  ]
}

export enum ThematicFocus {
  /**
   * Beteiligung, Engagement und Partizipation
   */
  PARTICIPATION = 'PARTICIPATION',

  /**
   * Bildung, Forschung und Wissenschaft
   */
  EDUCATION = 'EDUCATION',

  /**
   * Biodiversität, Artenschutz und Schutz natürlicher Ressourcen
   */
  BIODIVERSITY = 'BIODIVERSITY',

  /**
   * Demokratie und Menschenrechte
   */
  HUMAN_RIGHTS = 'HUMAN_RIGHTS',

  /**
   * Digitalisierung
   */
  DIGITALIZATION = 'DIGITALIZATION',

  /**
   * Diversität, Geschlechtergerechtigkeit, Inklusion und Anti-Diskriminierung
   */
  GENDER_EQUITY = 'GENDER_EQUITY',

  /**
   * Frieden und Sicherheit
   */
  PEACE = 'PEACE',

  /**
   * Internationale Verantwortung
   */
  INTERNATIONAL_RESPONSIBILITY = 'INTERNATIONAL_RESPONSIBILITY',

  /**
   * Klimaschutz und Energiewende
   */
  CLIMATE_PROTECTION = 'CLIMATE_PROTECTION',

  /**
   * Kreislaufwirtschaft
   */
  CIRCULAR_ECONOMY = 'CIRCULAR_ECONOMY',

  /**
   * Kultur, gesellschaftlicher Wandel und soziale Innovation
   */
  CULTURAL_SOCIAL_CHANGE = 'CULTURAL_SOCIAL_CHANGE',

  /**
   * Landwirtschaft und Ernährung
   */
  AGRICULTURE = 'AGRICULTURE',

  /**
   * Mobilität und Verkehrswende
   */
  MOBILITY = 'MOBILITY',

  /**
   * Nachhaltige Beschaffung
   */
  SUSTAINABLE_PROCUREMENT = 'SUSTAINABLE_PROCUREMENT',

  /**
   * Nachhaltiger Konsum und Lebensstile
   */
  SUSTAINABLE_LIFESTYLE = 'SUSTAINABLE_LIFESTYLE',

  /**
   * Nachhaltiges Bauen und Wohnen
   */
  SUSTAINABLE_BUILDING = 'SUSTAINABLE_BUILDING',

  /**
   * Nachhaltiges Wirtschaften
   */
  SUSTAINABLE_BUSINESS = 'SUSTAINABLE_BUSINESS',

  /**
   * Nachhaltigkeitsgovernance
   */
  SUSTAINABLE_GOVERNANCE = 'SUSTAINABLE_GOVERNANCE',

  /**
   * Soziale Gerechtigkeit, gute Arbeit und Chancengleichheit
   */
  SOCIAL_JUSTICE = 'SOCIAL_JUSTICE',

  /**
   * Stadtentwicklung, Entwicklung ländlicher Räume und Quartiersentwicklung
   */
  URBAN_DEVELOPMENT = 'URBAN_DEVELOPMENT',

  /**
   * Sustainable Finance
   */
  SUSTAINABLE_FINANCE = 'SUSTAINABLE_FINANCE',

  /**
   * Sport
   */
  SPORT = 'SPORT',

  /**
   * Tourismus
   */
  TOURISM = 'TOURISM',

  /**
   * Sonstiges
   */
  OTHER = 'OTHER',
}

export type Address = {
  name?: string
  street?: string
  streetNo?: string
  supplement?: string
  zipCode?: string
  city?: string
  state?: string
  country?: string
}
type LocationData = {
  address?: Address
  online?: boolean
  privateLocation?: boolean
  url?: string
  coordinate?: Point | null
}

export enum ActivityType {
  /**
   * Veranstaltung
   */
  EVENT = 'EVENT',

  /**
   * DAN
   */
  DAN = 'DAN',
}

export enum SpecialActivityType {
  /**
   * DAN
   */
  DAN = 'DAN',
  /**
   * DAN
   */
  EVENT = 'EVENT',
}

export interface Contact {
  position?: string
  lastName?: string
  firstName?: string
  email?: string
  phone?: string
  image?: string
}

export interface SocialMediaContact {
  type: SocialMediaType
  contact: string
}

export enum SocialMediaType {
  FACEBOOK = 'FACEBOOK',
  INSTAGRAM = 'INSTAGRAM',
  TIKTOK = 'TIKTOK',
  LINKEDIN = 'LINKEDIN',
  YOUTUBE = 'YOUTUBE',
  TWITTER = 'TWITTER',
}

export type Activity = {
  id?: number
  name?: string
  location?: LocationData
  sustainableDevelopmentGoals?: number[]
  thematicFocus?: ThematicFocus[]
  activityType?: ActivityType
  specialType?: SpecialActivityType
  description?: string
  impactArea?: string
  logo?: string
  image?: string
  contact?: Contact
  socialMediaContacts?: SocialMediaContact[]
  bannerImageMode?: 'cover' | 'contain'

  period?: {
    start: string
    end: string
    permanent?: boolean
  }
  organisation?: {
    id: number
    name: string
    logo: string
    image: string
  }
  isSubscribed?: boolean
  registerUrl?: string
}

type ActivityWIP = Activity & {
  privacyConsent?: boolean
  randomUniqueId?: string
}

export type EventDto = Activity & {
  resultType: string
}

type PageQuerParams = {
  page?: number
  size?: number
  sort?: string
}

type Paging = {
  number?: number
  size?: number
  totalElements?: number
  totalPages?: number
}

export type OpenApiResponse<T> = {
  content: T[]
} & Paging
